import { jsx as _jsx } from "@emotion/react/jsx-runtime";
import { useMemo, useEffect } from 'react';
import { useDispatch } from "react-redux";
import { CodeCell } from '@jupyterlab/cells';
import { cellActions } from './CellState';
import CellAdapter from './CellAdapter';
import LuminoAttached from '../../jupyter/lumino/LuminoAttached';
import '@jupyterlab/application/style/index.css';
import '@jupyterlab/cells/style/index.css';
import '@jupyterlab/completer/style/index.css';
// This should be only index.css, looks like jupyterlab has a regression here...
import '@jupyterlab/theme-light-extension/style/theme.css';
import '@jupyterlab/theme-light-extension/style/variables.css';
import './Cell.css';
const DEFAULT_SOURCE = `from IPython.display import display

for i in range(10):
    display('String {} added to the DOM in separated DIV.'.format(i))`;
const Cell = (props) => {
    const adapter = useMemo(() => new CellAdapter(props.source), []);
    const dispatch = useDispatch();
    useEffect(() => {
        dispatch(cellActions.update({ adapter }));
        dispatch(cellActions.source(props.source));
        adapter.codeCell.model.value.changed.connect((sender, changedArgs) => {
            dispatch(cellActions.source(sender.text));
        });
        adapter.codeCell.outputArea.outputLengthChanged.connect((_, outputsCount) => {
            dispatch(cellActions.outputsCount(outputsCount));
        });
        adapter.sessionContext.initialize().then(() => {
            if (props.autoStart) {
                const executePromise = CodeCell.execute(adapter.codeCell, adapter.sessionContext);
                executePromise.then((msg) => {
                    dispatch(cellActions.update({
                        kernelAvailable: true,
                    }));
                });
            }
        });
    }, []);
    return _jsx(LuminoAttached, { children: adapter.panel }, void 0);
};
Cell.defaultProps = {
    source: DEFAULT_SOURCE,
    autoStart: true,
};
export default Cell;
//# sourceMappingURL=Cell.js.map