import { jsx as _jsx } from "@emotion/react/jsx-runtime";
import { useRef, useEffect } from 'react';
import { basicSetup } from '@codemirror/basic-setup';
import { EditorState } from '@codemirror/state';
import { keymap, EditorView } from '@codemirror/view';
import { python } from '@codemirror/lang-python';
const CodeMirrorEditor = (props) => {
    const { code, outputAdapter, autoRun } = props;
    const editor = useRef();
    useEffect(() => {
        let state;
        const keyBinding = [
            { key: 'Shift-Enter', run: () => runCode(), preventDefault: true },
        ];
        state = EditorState.create({
            doc: code,
            extensions: [basicSetup, python(), keymap.of([...keyBinding])],
        });
        const view = new EditorView({
            state: state,
            parent: editor.current,
        });
        const runCode = () => {
            outputAdapter.execute(String(view.state.doc));
            return true;
        };
        if (autoRun) {
            runCode();
        }
        return () => {
            view.destroy();
        };
    }, []);
    return _jsx("div", { ref: editor }, void 0);
    /*
      return <div ref={ref => {
        if (ref) {
          const kb = [{key: "Shift-Enter", run: () => runCode(), preventDefault: true}];
          let state = EditorState.create({
            doc: code,
            extensions: [
              basicSetup,
              javascript(),
              keymap.of([...kb]),
            ]
          });
          const view = new EditorView({
            state: state,
            parent: ref,
          });
          const runCode = () => {
            Output.execute(String(view.state.doc));
            return true;
          };
          runCode();
        };
        return <div ref={ref as any}></div>
      }}/>;
    */
};
export default CodeMirrorEditor;
//# sourceMappingURL=CodeMirrorEditor.js.map