/// <reference types="react" />
import { AnyAction, Action, Success } from "typescript-fsa";
import { Epic } from "redux-observable";
import { NotebookChange } from "@jupyterlab/shared-models";
import { Cell, ICellModel } from "@jupyterlab/cells";
import { Kernel } from "@jupyterlab/services";
import { IState } from "./../../state/State";
import NotebookAdapter from "./NotebookAdapter";
export interface INotebookState {
    activeCell: Cell<ICellModel> | undefined;
    kernelStatus: Kernel.Status | undefined;
    notebookChange: NotebookChange | undefined;
    portals: React.ReactPortal[];
    adapter?: NotebookAdapter;
}
export declare const notebookInitialState: INotebookState;
export declare const selectNotebook: () => INotebookState;
export declare enum ActionType {
    UPDATE = "notebook/UPDATE",
    NOTEBOOK_CHANGE = "notebook/NOTEBOOK_CHANGE",
    ACTIVE_CELL_CHANGE = "notebook/ACTIVE_CELL_CHANGE",
    KERNEL_STATUS_CHANGE = "notebook/KERNEL_STATUS_CHANGE",
    RUN = "notebook/RUN",
    RUN_ALL = "notebook/RUN_ALL",
    SAVE = "notebook/SAVE",
    INTERRUPT = "notebook/INTERRUPT",
    INSERT_ABOVE = "notebook/INSERT_ABOVE",
    INSERT_BELOW = "notebook/INSERT_BELOW",
    DELETE = "notebook/DELETE",
    PORTAL = "notebook/PORTAL",
    SET_PORTALS = "notebook/SET_PORTALS"
}
export declare const notebookActions: {
    update: import("typescript-fsa").ActionCreator<Partial<INotebookState>>;
    notebookChange: import("typescript-fsa").ActionCreator<NotebookChange>;
    activeCellChange: import("typescript-fsa").ActionCreator<Cell<ICellModel>>;
    kernelStatusChanged: import("typescript-fsa").ActionCreator<Kernel.Status>;
    run: import("typescript-fsa").ActionCreator<void>;
    save: import("typescript-fsa").ActionCreator<void>;
    runAll: import("typescript-fsa").ActionCreator<void>;
    interrupt: import("typescript-fsa").ActionCreator<void>;
    portal: import("typescript-fsa").ActionCreator<import("react").ReactPortal>;
    setPortals: import("typescript-fsa").ActionCreator<import("react").ReactPortal[]>;
    insertAbove: import("typescript-fsa").AsyncActionCreators<void, void, {}>;
    insertBelow: import("typescript-fsa").AsyncActionCreators<void, void, {}>;
    delete: import("typescript-fsa").AsyncActionCreators<void, void, {}>;
};
export declare const notebookEpics: Epic<AnyAction, Action<Success<void, void>>, IState, any>;
export declare const notebookReducer: import("typescript-fsa-reducers").ReducerBuilder<INotebookState, INotebookState>;
