import { OutputArea } from '@jupyterlab/outputarea';
import { RenderMimeRegistry, standardRendererFactories } from '@jupyterlab/rendermime';
import { rendererFactory as jsonRendererFactory } from '@jupyterlab/json-extension';
import { IPyWidgetsClassicManager } from "../../jupyter/ipywidgets/IPyWidgetsClassicManager";
import { requireLoader } from "@jupyter-widgets/html-manager";
import { WIDGET_MIMETYPE, WidgetRenderer } from "@jupyter-widgets/html-manager/lib/output_renderers";
// import { activateWidgetExtension } from "../../ipywidgets/IPyWidgetsJupyterLabPlugin";
// import { activatePlotlyWidgetExtension } from "../../ipywidgets/plotly/jupyterlab-plugin";
import '@lumino/default-theme/style/index.css';
import '@jupyterlab/json-extension/style/index.css';
import './OutputAdapter.css';
class OutputAdapter {
    constructor(kernel, model, options = {}) {
        this._kernelConnectionPromise = kernel;
        this._msgLoading = options.msgLoading || 'Loading...';
        this._iPyWidgetsClassicManager = new IPyWidgetsClassicManager({ loader: requireLoader });
        this._renderers = standardRendererFactories.filter(_ => true);
        this._renderers.push(jsonRendererFactory);
        this._rendermime = new RenderMimeRegistry({
            initialFactories: this._renderers,
        });
        this._rendermime.addFactory({
            safe: false,
            mimeTypes: [WIDGET_MIMETYPE],
            createRenderer: (options) => new WidgetRenderer(options, this._iPyWidgetsClassicManager),
        }, 0);
        //    const widgetRegistry = activateWidgetExtension(this._rendermime, null, null, null);
        //    activatePlotlyWidgetExtension(widgetRegistry);
        if (this._kernelConnectionPromise) {
            this._kernelConnectionPromise.then((kernelConnection) => {
                this._iPyWidgetsClassicManager.registerWithKernel(kernelConnection);
            });
        }
        if (!options.noAutoInit) {
            this.renderCell(model);
        }
    }
    renderCell(model) {
        this._outputArea = new OutputArea({
            model: model,
            rendermime: this._rendermime,
        });
    }
    execute(code) {
        if (this._kernelConnectionPromise) {
            this._outputArea.model.clear();
            this.render(code);
            return;
        }
    }
    clearOutput() {
        this._outputArea.model.clear();
    }
    render(code) {
        this._kernelConnectionPromise.then((kernelConnection) => {
            this._outputArea.future = kernelConnection.requestExecute({ code });
        });
        this._outputArea.model.add({
            output_type: 'stream',
            name: 'loading',
            text: this._msgLoading,
        });
        this._outputArea.model.clear(true);
    }
    get panel() {
        return this._outputArea;
    }
}
export default OutputAdapter;
//# sourceMappingURL=OutputAdapter.js.map