import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
import { PageConfig } from '@jupyterlab/coreutils';
import { ErrorBoundary } from 'react-error-boundary';
import injectableStore from '../state/Store';
import { JupyterContextProvider } from './JupyterContext';
import { loadJupyterConfig, getJupyterServerHttpUrl, getJupyterServerWsUrl, getJupyterToken } from './JupyterConfig';
/**
 * The component to be used as fallback in case of error.
 */
const ErrorFallback = ({ error, resetErrorBoundary }) => {
    return (_jsxs("div", Object.assign({ role: "alert" }, { children: [_jsx("p", { children: "Oops, something went wrong." }, void 0),
            _jsx("pre", { children: error.message }, void 0)] }), void 0));
};
/**
 * The Jupyter context. This handles the needed initialization
 * and ensure the Redux and the Material UI theme providers
 * are available.
 */
export const Jupyter = (props) => {
    loadJupyterConfig();
    const baseUrl = props.jupyterServerHttpUrl || getJupyterServerHttpUrl();
    PageConfig.setOption('baseUrl', baseUrl);
    PageConfig.setOption('collaborative', String(props.collaborative || false));
    PageConfig.setOption('mathjaxUrl', 'https://cdnjs.cloudflare.com/ajax/libs/mathjax/2.7.5/MathJax.js');
    PageConfig.setOption('mathjaxConfig', 'TeX-AMS_CHTML-full,Safe');
    PageConfig.setOption('terminalsAvailable', String(props.terminals || false));
    PageConfig.setOption('token', props.jupyterToken || getJupyterToken());
    const wsUrl = props.jupyterServerWsUrl || getJupyterServerWsUrl();
    PageConfig.setOption('wsUrl', wsUrl);
    return (_jsx(ErrorBoundary, Object.assign({ FallbackComponent: ErrorFallback, onReset: () => {
            console.log('The reset button has been clicked...');
        } }, { children: _jsx(JupyterContextProvider, Object.assign({ variant: "default", baseUrl: baseUrl, wsUrl: wsUrl, injectableStore: props.injectableStore || injectableStore }, { children: props.children }), void 0) }), void 0));
};
export default Jupyter;
//# sourceMappingURL=Jupyter.js.map