import { jsx as _jsx } from "@emotion/react/jsx-runtime";
import { useState, useEffect, useContext, createContext } from "react";
import { Provider as ReduxProvider } from "react-redux";
import { getJupyterServerHttpUrl } from './JupyterConfig';
import { requestAPI } from './Handlers';
/**
 * The instance for the Jupyter context.
 */
export const JupyterContext = createContext(undefined);
export function useJupyter() {
    const context = useContext(JupyterContext);
    if (!context)
        throw new Error("useContext must be inside a Provider with a value.");
    return context;
}
/**
 * The type for the Jupyter context consumer.
 */
export const JupyterContextConsumer = JupyterContext.Consumer;
/**
 * The type for the Jupyter context provider.
 */
const JupyterProvider = JupyterContext.Provider;
/**
 * Utiliy method to ensure the Jupyter context is authenticated
 * with the Jupyter server.
 */
export const ensureJupyterAuth = () => {
    return requestAPI('api', '', {
        credentials: 'include',
        mode: 'cors',
    })
        .then(data => {
        return true;
    })
        .catch(reason => {
        console.log('The jupyter server API has failed with reason', reason);
        return false;
    });
};
/**
 * The Jupyter context provider.
 */
export const JupyterContextProvider = ({ children, variant, baseUrl, wsUrl, injectableStore }) => {
    const [, setVariant] = useState('');
    useEffect(() => {
        ensureJupyterAuth().then(isAuth => {
            if (!isAuth) {
                const loginUrl = getJupyterServerHttpUrl() + '/login?next=' + window.location;
                console.log('Redirecting to jupyter login url: ', loginUrl);
                window.location.replace(loginUrl);
            }
        });
        setVariant(variant);
    }, [variant]);
    return (_jsx(ReduxProvider, Object.assign({ store: injectableStore }, { children: _jsx(JupyterProvider, Object.assign({ value: {
                variant,
                setVariant,
                baseUrl,
                wsUrl,
                injectableStore
            } }, { children: children }), void 0) }), void 0));
};
//# sourceMappingURL=JupyterContext.js.map